@@ -5,10 +5,10 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '1.8.1';
-
 use MP3::ID3Lib;
 
+our $VERSION = sprintf "%d.%02d", '$Revision: 1.2 $ ' =~ /(\d+)\.(\d+)/;
+
 my %data = (artist => 'TPE1',
             title  => 'TIT2',
             album  => 'TALB',
@@ -19,8 +19,6 @@ my %data = (artist => 'TPE1',
 sub new {
   my $class = shift;
   my $file = shift;
-
-  croak __PACKAGE__ . '->new called without an MP3 file' unless defined $file;
   my $obj = MP3::ID3Lib->new($file);
 
   bless { obj => $obj }, $class;
@@ -35,21 +33,6 @@ sub AUTOLOAD {
 
   die "Invalid attribute $sub" unless exists $data{$sub};
 
-  if ($_[1]) {
-    my $attr = $_[1];
-    my $found;
-    for (@{$_[0]->{obj}->frames}) {
-      if($_->code eq $data{$sub}) {
-      $found = 1;
-      $_->set($attr);
-        last;
-      }
-    }
-
-    $_[0]->{obj}->add_frame($data{$sub}, $attr) unless $found;
-    $_[0]->{obj}->commit;
-  }
-
   for (@{$_[0]->{obj}->frames}) {
     return $_->value if $_->code eq $data{$sub};
   }
@@ -66,17 +49,10 @@ AudioFile::Info::MP3::ID3Lib - Perl extension to get info from MP3 files.
 =head1 DESCRIPTION
 
 This is a plugin for AudioFile::Info which uses MP3::ID3Lib to get
-data about MP3 files.
+data about MP files.
 
 See L<AudioFile::Info> for more details.
 
-=head1 METHODS
-
-=head2 new
-
-Creates a new object of class AudioFile::Info::MP3::ID3Lib. Usually called
-by AudioFile::Info::new.
-
 =head1 AUTHOR
 
 Dave Cross, E<lt>dave@dave.org.ukE<gt>
@@ -86,6 +62,6 @@ Dave Cross, E<lt>dave@dave.org.ukE<gt>
 Copyright 2003 by Dave Cross
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the same terms as Perl itself. 
 
 =cut
